pub enum C {
C(char),
N(u32),
}Expand description
Represents a single character in one of the programs on the tape. Because unicode doesn’t define valid characters for every single 32-bit bitmask, this value allows switching between interpreting the character as a number or as a unicode codepoint.
Variants
Implementations